@@ -23,12 +23,15 @@ import collective.volto.subfooter
 import collective.volto.subsites
 import design.plone.contenttypes
 import design.plone.policy
+import kitconcept.seo
 import plone.app.caching
 import plone.formwidget.geolocation
 import plone.restapi
 import redturtle.bandi
 import redturtle.volto
 import redturtle.voltoplugin.editablefooter
+import rer.customersatisfaction
+import souper.plone
 
 
 class FauxRequest(dict):
@@ -54,6 +57,7 @@ class DesignPlonePolicyLayer(PloneSandboxLayer):
         self.loadZCML(package=collective.volto.subsites)
         self.loadZCML(package=design.plone.contenttypes)
         self.loadZCML(package=design.plone.policy)
+        self.loadZCML(package=kitconcept.seo)
         self.loadZCML(package=plone.app.caching)
         self.loadZCML(package=plone.formwidget.geolocation)
         self.loadZCML(package=plone.restapi)
@@ -62,6 +66,8 @@ class DesignPlonePolicyLayer(PloneSandboxLayer):
         self.loadZCML(package=redturtle.voltoplugin.editablefooter)
         self.loadZCML(package=collective.dexteritytextindexer)
         self.loadZCML(package=collective.volto.subfooter)
+        self.loadZCML(package=rer.customersatisfaction)
+        self.loadZCML(package=souper.plone)
 
     def setUpPloneSite(self, portal):
         request = FauxRequest()
@@ -113,6 +119,7 @@ class DesignPlonePolicyRestApiLayer(PloneRestApiDXLayer):
         self.loadZCML(package=collective.volto.subsites)
         self.loadZCML(package=design.plone.contenttypes)
         self.loadZCML(package=design.plone.policy)
+        self.loadZCML(package=kitconcept.seo)
         self.loadZCML(package=plone.app.caching)
         self.loadZCML(package=plone.formwidget.geolocation)
         self.loadZCML(package=plone.restapi)
@@ -120,6 +127,8 @@ class DesignPlonePolicyRestApiLayer(PloneRestApiDXLayer):
         self.loadZCML(package=redturtle.volto)
         self.loadZCML(package=redturtle.voltoplugin.editablefooter)
         self.loadZCML(package=collective.volto.subfooter)
+        self.loadZCML(package=rer.customersatisfaction)
+        self.loadZCML(package=souper.plone)
 
     def setUpPloneSite(self, portal):
         request = FauxRequest()
